Index: /CKEditor/trunk/CHANGES.html
===================================================================
--- /CKEditor/trunk/CHANGES.html	(revision 5386)
+++ /CKEditor/trunk/CHANGES.html	(revision 5387)
@@ -155,4 +155,5 @@
 			<li><a href="http://dev.fckeditor.net/ticket/5301">#5301</a> : Norwegian;</li>
 		</ul></li>
+		<li><a href="http://dev.fckeditor.net/ticket/5416">#5416</a> : [IE] Delete table throws a error when  CKEDITOR.enterMode = CKEDITOR.ENTER_BR.</li>
 	</ul>
 	<h3>
Index: /CKEditor/trunk/_source/plugins/tabletools/plugin.js
===================================================================
--- /CKEditor/trunk/_source/plugins/tabletools/plugin.js	(revision 5386)
+++ /CKEditor/trunk/_source/plugins/tabletools/plugin.js	(revision 5387)
@@ -727,7 +727,8 @@
 						selection.selectRanges( [ range ] );
 
-						// If the table's parent has only one child, remove it as well.
-						if ( table.getParent().getChildCount() == 1 )
-							table.getParent().remove();
+						// If the table's parent has only one child, remove it,except body,as well.( #5416 )
+						var parent = table.getParent();
+						if ( parent.getChildCount() == 1 && parent.getName() != 'body' )
+							parent.remove();
 						else
 							table.remove();
